# rapidata.api-client
No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The `rapidata.api_client` package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: v1
- Package version: 1.0.0
- Generator version: 7.9.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 3.7+

## Installation & Usage

This python library package is generated without supporting files like setup.py or requirements files

To be able to use it, you will need these dependencies in your own package that uses this library:

* urllib3 >= 1.25.3, < 3.0.0
* python-dateutil >= 2.8.2
* pydantic >= 2
* typing-extensions >= 4.7.1

## Getting Started

In your own code, to use this library to connect and interact with rapidata.api-client,
you can run the following:

```python

import rapidata.api_client
from rapidata.api_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to http://localhost
# See configuration.py for a list of all supported configuration parameters.
configuration = rapidata.api_client.Configuration(
    host = "http://localhost"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: bearer
configuration.api_key['bearer'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['bearer'] = 'Bearer'


# Enter a context with an instance of the API client
with rapidata.api_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = rapidata.api_client.CampaignApi(api_client)

    try:
        # The monitor endpoint is used to monitor the health of the service
        api_instance.campaign_monitor_get()
    except ApiException as e:
        print("Exception when calling CampaignApi->campaign_monitor_get: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *http://localhost*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*CampaignApi* | [**campaign_monitor_get**](rapidata/api_client/docs/CampaignApi.md#campaign_monitor_get) | **GET** /Campaign/Monitor | The monitor endpoint is used to monitor the health of the service
*CampaignApi* | [**campaign_pause_post**](rapidata/api_client/docs/CampaignApi.md#campaign_pause_post) | **POST** /Campaign/Pause | Pauses a campaign.
*CampaignApi* | [**campaign_query_get**](rapidata/api_client/docs/CampaignApi.md#campaign_query_get) | **GET** /Campaign/Query | Queries orders based on a filter, page, and sort criteria.
*CampaignApi* | [**campaign_resume_post**](rapidata/api_client/docs/CampaignApi.md#campaign_resume_post) | **POST** /Campaign/Resume | Resumes a campaign.
*ClientApi* | [**client_client_id_delete**](rapidata/api_client/docs/ClientApi.md#client_client_id_delete) | **DELETE** /Client/{clientId} | Deletes a customers client.
*ClientApi* | [**client_post**](rapidata/api_client/docs/ClientApi.md#client_post) | **POST** /Client | Creates a new client for the current customer.
*ClientApi* | [**client_query_get**](rapidata/api_client/docs/ClientApi.md#client_query_get) | **GET** /Client/Query | Gets the clients for the current customer.
*CocoApi* | [**coco_submit_post**](rapidata/api_client/docs/CocoApi.md#coco_submit_post) | **POST** /Coco/Submit | Creates a new validation set based on a previously uploaded CoCo set.
*CocoApi* | [**coco_upload_post**](rapidata/api_client/docs/CocoApi.md#coco_upload_post) | **POST** /Coco/Upload | Uploads a CoCo set to the system.
*CompareWorkflowApi* | [**compare_workflow_get_result_overview_get**](rapidata/api_client/docs/CompareWorkflowApi.md#compare_workflow_get_result_overview_get) | **GET** /CompareWorkflow/GetResultOverview | Get the result overview for a compare workflow.
*DatapointApi* | [**datapoint_delete_delete**](rapidata/api_client/docs/DatapointApi.md#datapoint_delete_delete) | **DELETE** /Datapoint/Delete | Delete a datapoint.
*DatapointApi* | [**datapoint_get_all_datapoints_by_dataset_id_get**](rapidata/api_client/docs/DatapointApi.md#datapoint_get_all_datapoints_by_dataset_id_get) | **GET** /Datapoint/GetAllDatapointsByDatasetId | Get all datapoints of a dataset.
*DatapointApi* | [**datapoint_get_by_id_get**](rapidata/api_client/docs/DatapointApi.md#datapoint_get_by_id_get) | **GET** /Datapoint/GetById | Get a datapoint by its id.
*DatasetApi* | [**dataset_creat_text_datapoint_post**](rapidata/api_client/docs/DatasetApi.md#dataset_creat_text_datapoint_post) | **POST** /Dataset/CreatTextDatapoint | Creates new datapoints from text sources.
*DatasetApi* | [**dataset_create_datapoint_post**](rapidata/api_client/docs/DatasetApi.md#dataset_create_datapoint_post) | **POST** /Dataset/CreateDatapoint | Creates a single datapoint.
*DatasetApi* | [**dataset_get_by_id_get**](rapidata/api_client/docs/DatasetApi.md#dataset_get_by_id_get) | **GET** /Dataset/GetById | Gets a dataset by its id.
*DatasetApi* | [**dataset_import_post**](rapidata/api_client/docs/DatasetApi.md#dataset_import_post) | **POST** /Dataset/Import | Imports datapoints from a csv file.
*DatasetApi* | [**dataset_update_name_post**](rapidata/api_client/docs/DatasetApi.md#dataset_update_name_post) | **POST** /Dataset/UpdateName | Updates the name of a dataset.
*DatasetApi* | [**dataset_upload_datapoint_post**](rapidata/api_client/docs/DatasetApi.md#dataset_upload_datapoint_post) | **POST** /Dataset/UploadDatapoint | Creates a new multi asset datapoint.
*DatasetApi* | [**dataset_upload_files_from_s3_post**](rapidata/api_client/docs/DatasetApi.md#dataset_upload_files_from_s3_post) | **POST** /Dataset/UploadFilesFromS3 | Uploads files from an S3 bucket to a dataset.
*DatasetApi* | [**dataset_upload_images_to_dataset_post**](rapidata/api_client/docs/DatasetApi.md#dataset_upload_images_to_dataset_post) | **POST** /Dataset/UploadImagesToDataset | Uploads images to a dataset.
*IdentityApi* | [**identity_create_bridge_token_post**](rapidata/api_client/docs/IdentityApi.md#identity_create_bridge_token_post) | **POST** /Identity/CreateBridgeToken | Creates a pair of read and write keys for a client.  The write key is used to store the authentication result.  The read key is used to retrieve the authentication result.
*IdentityApi* | [**identity_read_bridge_token_get**](rapidata/api_client/docs/IdentityApi.md#identity_read_bridge_token_get) | **GET** /Identity/ReadBridgeToken | Tries to read the bridge token keys for a given read key.  The read key is used to retrieve the authentication result written by the write key.
*IdentityApi* | [**identity_register_temporary_post**](rapidata/api_client/docs/IdentityApi.md#identity_register_temporary_post) | **POST** /Identity/RegisterTemporary | Registers and logs in a temporary customer.
*NewsletterApi* | [**newsletter_post**](rapidata/api_client/docs/NewsletterApi.md#newsletter_post) | **POST** /Newsletter | Signs a user up to the newsletter.
*NewsletterApi* | [**newsletter_unsubscribe_post**](rapidata/api_client/docs/NewsletterApi.md#newsletter_unsubscribe_post) | **POST** /Newsletter/Unsubscribe | Unsubscribes a user from the newsletter.
*OrderApi* | [**order_approve_post**](rapidata/api_client/docs/OrderApi.md#order_approve_post) | **POST** /Order/Approve | Approves an order that has been submitted for manual approval.
*OrderApi* | [**order_clone_order_post**](rapidata/api_client/docs/OrderApi.md#order_clone_order_post) | **POST** /Order/CloneOrder | Clones an existing order.
*OrderApi* | [**order_create_complex_order_post**](rapidata/api_client/docs/OrderApi.md#order_create_complex_order_post) | **POST** /Order/CreateComplexOrder | Creates a new order with a custom pipeline.
*OrderApi* | [**order_create_post**](rapidata/api_client/docs/OrderApi.md#order_create_post) | **POST** /Order/Create | Used to create a new order.
*OrderApi* | [**order_create_unsupported_order_post**](rapidata/api_client/docs/OrderApi.md#order_create_unsupported_order_post) | **POST** /Order/CreateUnsupportedOrder | Notifies the admins that a user wants to create an order with an unsupported label type or data type.
*OrderApi* | [**order_delete_delete**](rapidata/api_client/docs/OrderApi.md#order_delete_delete) | **DELETE** /Order/Delete | Deletes an order.
*OrderApi* | [**order_feedback_post**](rapidata/api_client/docs/OrderApi.md#order_feedback_post) | **POST** /Order/Feedback | Submits feedback about our services.
*OrderApi* | [**order_get_by_id_get**](rapidata/api_client/docs/OrderApi.md#order_get_by_id_get) | **GET** /Order/GetById | Retrieves an order by its id.
*OrderApi* | [**order_get_order_results_get**](rapidata/api_client/docs/OrderApi.md#order_get_order_results_get) | **GET** /Order/GetOrderResults | Aggregates the results of an order.
*OrderApi* | [**order_get_public_get**](rapidata/api_client/docs/OrderApi.md#order_get_public_get) | **GET** /Order/GetPublic | Retrieves orders that are public and can be cloned by any user.
*OrderApi* | [**order_pause_post**](rapidata/api_client/docs/OrderApi.md#order_pause_post) | **POST** /Order/Pause | Pauses an order that is processing. Meaning all campaigns in the order will be paused.
*OrderApi* | [**order_query_get**](rapidata/api_client/docs/OrderApi.md#order_query_get) | **GET** /Order/Query | Queries orders based on a filter, page, and sort criteria.
*OrderApi* | [**order_result_get**](rapidata/api_client/docs/OrderApi.md#order_result_get) | **GET** /Order/Result | Aggregates the results of an order.
*OrderApi* | [**order_resume_post**](rapidata/api_client/docs/OrderApi.md#order_resume_post) | **POST** /Order/Resume | Resumes a paused order. Meaning all campaigns in the order will be resumed.
*OrderApi* | [**order_retry_failed_post**](rapidata/api_client/docs/OrderApi.md#order_retry_failed_post) | **POST** /Order/RetryFailed | Retries a failed order.
*OrderApi* | [**order_share_put**](rapidata/api_client/docs/OrderApi.md#order_share_put) | **PUT** /Order/Share | Updates whether an order is public or not.
*OrderApi* | [**order_submit_post**](rapidata/api_client/docs/OrderApi.md#order_submit_post) | **POST** /Order/Submit | Submits an order for approval.
*OrderApi* | [**order_unlock_post**](rapidata/api_client/docs/OrderApi.md#order_unlock_post) | **POST** /Order/Unlock | Unlocks a newly cloned order.
*OrderApi* | [**order_update_access_put**](rapidata/api_client/docs/OrderApi.md#order_update_access_put) | **PUT** /Order/UpdateAccess | Updates whether an order is public or not.
*OrderApi* | [**order_update_order_name_put**](rapidata/api_client/docs/OrderApi.md#order_update_order_name_put) | **PUT** /Order/UpdateOrderName | Updates the name of an order.
*PipelineApi* | [**pipeline_id_campaign_artifact_id_put**](rapidata/api_client/docs/PipelineApi.md#pipeline_id_campaign_artifact_id_put) | **PUT** /pipeline/{id}/campaign/{artifact-id} | Updates a specific campaign for a pipeline.
*PipelineApi* | [**pipeline_id_campaign_post**](rapidata/api_client/docs/PipelineApi.md#pipeline_id_campaign_post) | **POST** /pipeline/{id}/campaign | Adds a campaign to a pipeline.
*PipelineApi* | [**pipeline_id_campaign_put**](rapidata/api_client/docs/PipelineApi.md#pipeline_id_campaign_put) | **PUT** /pipeline/{id}/campaign | Updates the default campaign for a pipeline.
*PipelineApi* | [**pipeline_id_get**](rapidata/api_client/docs/PipelineApi.md#pipeline_id_get) | **GET** /Pipeline/{id} | Gets a pipeline by its id.
*PipelineApi* | [**pipeline_id_workflow_artifact_id_put**](rapidata/api_client/docs/PipelineApi.md#pipeline_id_workflow_artifact_id_put) | **PUT** /pipeline/{id}/workflow/{artifact-id} | Updates the workflow configuration for a pipeline.
*PipelineApi* | [**pipeline_id_workflow_put**](rapidata/api_client/docs/PipelineApi.md#pipeline_id_workflow_put) | **PUT** /pipeline/{id}/workflow | Updates the workflow configuration for a pipeline.
*RapidApi* | [**rapid_add_user_guess_post**](rapidata/api_client/docs/RapidApi.md#rapid_add_user_guess_post) | **POST** /Rapid/AddUserGuess | Submits a user guess for a Rapid.
*RapidApi* | [**rapid_create_demographic_rapid_post**](rapidata/api_client/docs/RapidApi.md#rapid_create_demographic_rapid_post) | **POST** /Rapid/CreateDemographicRapid | Creates a new Demographic Rapid.
*RapidApi* | [**rapid_query_validation_rapids_get**](rapidata/api_client/docs/RapidApi.md#rapid_query_validation_rapids_get) | **GET** /Rapid/QueryValidationRapids | Queries the validation rapids for a specific validation set.
*RapidApi* | [**rapid_skip_user_guess_post**](rapidata/api_client/docs/RapidApi.md#rapid_skip_user_guess_post) | **POST** /Rapid/SkipUserGuess | Skips a Rapid for the user.
*RapidApi* | [**rapid_validate_current_rapid_bag_get**](rapidata/api_client/docs/RapidApi.md#rapid_validate_current_rapid_bag_get) | **GET** /Rapid/ValidateCurrentRapidBag | Validates that the rapids associated with the current user are active.
*RapidataIdentityAPIApi* | [**root_get**](rapidata/api_client/docs/RapidataIdentityAPIApi.md#root_get) | **GET** / | 
*SimpleWorkflowApi* | [**simple_workflow_get_result_overview_get**](rapidata/api_client/docs/SimpleWorkflowApi.md#simple_workflow_get_result_overview_get) | **GET** /SimpleWorkflow/GetResultOverview | Get the result overview for a simple workflow.
*UserInfoApi* | [**connect_userinfo_get**](rapidata/api_client/docs/UserInfoApi.md#connect_userinfo_get) | **GET** /connect/userinfo | Retrieves information about the authenticated user.
*ValidationApi* | [**validation_add_validation_rapid_post**](rapidata/api_client/docs/ValidationApi.md#validation_add_validation_rapid_post) | **POST** /Validation/AddValidationRapid | Adds a new validation rapid to the specified validation set.
*ValidationApi* | [**validation_add_validation_text_rapid_post**](rapidata/api_client/docs/ValidationApi.md#validation_add_validation_text_rapid_post) | **POST** /Validation/AddValidationTextRapid | Adds a new validation rapid to the specified validation set.
*ValidationApi* | [**validation_create_validation_set_post**](rapidata/api_client/docs/ValidationApi.md#validation_create_validation_set_post) | **POST** /Validation/CreateValidationSet | Creates a new empty validation set.
*ValidationApi* | [**validation_get_available_validation_sets_get**](rapidata/api_client/docs/ValidationApi.md#validation_get_available_validation_sets_get) | **GET** /Validation/GetAvailableValidationSets | Gets the available validation sets for the current user.
*ValidationApi* | [**validation_get_by_id_get**](rapidata/api_client/docs/ValidationApi.md#validation_get_by_id_get) | **GET** /Validation/GetById | Gets a validation set by the id.
*ValidationApi* | [**validation_import_compare_post**](rapidata/api_client/docs/ValidationApi.md#validation_import_compare_post) | **POST** /Validation/ImportCompare | Imports a compare validation set from a zip file.
*ValidationApi* | [**validation_import_post**](rapidata/api_client/docs/ValidationApi.md#validation_import_post) | **POST** /Validation/Import | Imports a validation set from a zip file.
*ValidationApi* | [**validation_query_validation_sets_get**](rapidata/api_client/docs/ValidationApi.md#validation_query_validation_sets_get) | **GET** /Validation/QueryValidationSets | Queries validation sets based on the provided filter, paging and sorting criteria.
*WorkflowApi* | [**workflow_delete_delete**](rapidata/api_client/docs/WorkflowApi.md#workflow_delete_delete) | **DELETE** /Workflow/Delete | Deletes a workflow.
*WorkflowApi* | [**workflow_get_by_id_get**](rapidata/api_client/docs/WorkflowApi.md#workflow_get_by_id_get) | **GET** /Workflow/GetById | Get a workflow by its ID.
*WorkflowApi* | [**workflow_get_progress_get**](rapidata/api_client/docs/WorkflowApi.md#workflow_get_progress_get) | **GET** /Workflow/GetProgress | Get the progress of a workflow.
*WorkflowApi* | [**workflow_get_result_overview_get**](rapidata/api_client/docs/WorkflowApi.md#workflow_get_result_overview_get) | **GET** /Workflow/GetResultOverview | Get the result overview for a workflow.
*WorkflowApi* | [**workflow_query_get**](rapidata/api_client/docs/WorkflowApi.md#workflow_query_get) | **GET** /Workflow/Query | Queries workflows based on the provided filter, page, and sort criteria.


## Documentation For Models

 - [AddCampaignArtifactResult](rapidata/api_client/docs/AddCampaignArtifactResult.md)
 - [AddCampaignModel](rapidata/api_client/docs/AddCampaignModel.md)
 - [AddValidationRapidModel](rapidata/api_client/docs/AddValidationRapidModel.md)
 - [AddValidationRapidModelPayload](rapidata/api_client/docs/AddValidationRapidModelPayload.md)
 - [AddValidationRapidModelTruth](rapidata/api_client/docs/AddValidationRapidModelTruth.md)
 - [AddValidationRapidResult](rapidata/api_client/docs/AddValidationRapidResult.md)
 - [AddValidationTextRapidModel](rapidata/api_client/docs/AddValidationTextRapidModel.md)
 - [AgeGroup](rapidata/api_client/docs/AgeGroup.md)
 - [AgeUserFilterModel](rapidata/api_client/docs/AgeUserFilterModel.md)
 - [AggregatorType](rapidata/api_client/docs/AggregatorType.md)
 - [AttachCategoryRapidBlueprint](rapidata/api_client/docs/AttachCategoryRapidBlueprint.md)
 - [AttachCategoryResult](rapidata/api_client/docs/AttachCategoryResult.md)
 - [AttachCategoryTruth](rapidata/api_client/docs/AttachCategoryTruth.md)
 - [BaseError](rapidata/api_client/docs/BaseError.md)
 - [BoundingBoxPayload](rapidata/api_client/docs/BoundingBoxPayload.md)
 - [BoundingBoxRapidBlueprint](rapidata/api_client/docs/BoundingBoxRapidBlueprint.md)
 - [BoundingBoxResult](rapidata/api_client/docs/BoundingBoxResult.md)
 - [BoundingBoxTruth](rapidata/api_client/docs/BoundingBoxTruth.md)
 - [BoxShape](rapidata/api_client/docs/BoxShape.md)
 - [CampaignArtifactModel](rapidata/api_client/docs/CampaignArtifactModel.md)
 - [CampaignQueryModel](rapidata/api_client/docs/CampaignQueryModel.md)
 - [CampaignQueryModelPagedResult](rapidata/api_client/docs/CampaignQueryModelPagedResult.md)
 - [CampaignStatus](rapidata/api_client/docs/CampaignStatus.md)
 - [CampaignUserFilterModel](rapidata/api_client/docs/CampaignUserFilterModel.md)
 - [CappedSelection](rapidata/api_client/docs/CappedSelection.md)
 - [CappedSelectionSelectionsInner](rapidata/api_client/docs/CappedSelectionSelectionsInner.md)
 - [ClassificationMetadata](rapidata/api_client/docs/ClassificationMetadata.md)
 - [ClassificationMetadataFilterConfig](rapidata/api_client/docs/ClassificationMetadataFilterConfig.md)
 - [ClassificationMetadataModel](rapidata/api_client/docs/ClassificationMetadataModel.md)
 - [ClassifyPayload](rapidata/api_client/docs/ClassifyPayload.md)
 - [ClientsQueryResult](rapidata/api_client/docs/ClientsQueryResult.md)
 - [ClientsQueryResultPagedResult](rapidata/api_client/docs/ClientsQueryResultPagedResult.md)
 - [CloneDatasetModel](rapidata/api_client/docs/CloneDatasetModel.md)
 - [CloneOrderModel](rapidata/api_client/docs/CloneOrderModel.md)
 - [CloneOrderResult](rapidata/api_client/docs/CloneOrderResult.md)
 - [ComparePayload](rapidata/api_client/docs/ComparePayload.md)
 - [CompareRapidBlueprint](rapidata/api_client/docs/CompareRapidBlueprint.md)
 - [CompareResult](rapidata/api_client/docs/CompareResult.md)
 - [CompareTruth](rapidata/api_client/docs/CompareTruth.md)
 - [CompareWorkflowConfig](rapidata/api_client/docs/CompareWorkflowConfig.md)
 - [CompareWorkflowConfigModel](rapidata/api_client/docs/CompareWorkflowConfigModel.md)
 - [CompareWorkflowConfigModelPairMakerConfig](rapidata/api_client/docs/CompareWorkflowConfigModelPairMakerConfig.md)
 - [CompareWorkflowConfigPairMakerConfig](rapidata/api_client/docs/CompareWorkflowConfigPairMakerConfig.md)
 - [CompareWorkflowGetResultOverviewGet200Response](rapidata/api_client/docs/CompareWorkflowGetResultOverviewGet200Response.md)
 - [CompareWorkflowModel](rapidata/api_client/docs/CompareWorkflowModel.md)
 - [CompareWorkflowModel1](rapidata/api_client/docs/CompareWorkflowModel1.md)
 - [CompareWorkflowModel1PairMakerInformation](rapidata/api_client/docs/CompareWorkflowModel1PairMakerInformation.md)
 - [CompareWorkflowModel1Referee](rapidata/api_client/docs/CompareWorkflowModel1Referee.md)
 - [CompareWorkflowModelPairMakerConfig](rapidata/api_client/docs/CompareWorkflowModelPairMakerConfig.md)
 - [CompletedRapidModel](rapidata/api_client/docs/CompletedRapidModel.md)
 - [CompletedRapidModelAsset](rapidata/api_client/docs/CompletedRapidModelAsset.md)
 - [ConditionalValidationSelection](rapidata/api_client/docs/ConditionalValidationSelection.md)
 - [Coordinate](rapidata/api_client/docs/Coordinate.md)
 - [CountClassificationMetadataFilterConfig](rapidata/api_client/docs/CountClassificationMetadataFilterConfig.md)
 - [CountMetadata](rapidata/api_client/docs/CountMetadata.md)
 - [CountMetadataModel](rapidata/api_client/docs/CountMetadataModel.md)
 - [CountryUserFilterModel](rapidata/api_client/docs/CountryUserFilterModel.md)
 - [CreateBridgeTokenResult](rapidata/api_client/docs/CreateBridgeTokenResult.md)
 - [CreateClientModel](rapidata/api_client/docs/CreateClientModel.md)
 - [CreateClientResult](rapidata/api_client/docs/CreateClientResult.md)
 - [CreateComplexOrderModel](rapidata/api_client/docs/CreateComplexOrderModel.md)
 - [CreateComplexOrderModelPipeline](rapidata/api_client/docs/CreateComplexOrderModelPipeline.md)
 - [CreateComplexOrderResult](rapidata/api_client/docs/CreateComplexOrderResult.md)
 - [CreateDatasetArtifactModel](rapidata/api_client/docs/CreateDatasetArtifactModel.md)
 - [CreateDatasetArtifactModelDataset](rapidata/api_client/docs/CreateDatasetArtifactModelDataset.md)
 - [CreateDemographicRapidModel](rapidata/api_client/docs/CreateDemographicRapidModel.md)
 - [CreateEmptyValidationSetResult](rapidata/api_client/docs/CreateEmptyValidationSetResult.md)
 - [CreateOrderModel](rapidata/api_client/docs/CreateOrderModel.md)
 - [CreateOrderModelReferee](rapidata/api_client/docs/CreateOrderModelReferee.md)
 - [CreateOrderModelUserFiltersInner](rapidata/api_client/docs/CreateOrderModelUserFiltersInner.md)
 - [CreateOrderModelWorkflow](rapidata/api_client/docs/CreateOrderModelWorkflow.md)
 - [CreateOrderResult](rapidata/api_client/docs/CreateOrderResult.md)
 - [CreateSimplePipelineModel](rapidata/api_client/docs/CreateSimplePipelineModel.md)
 - [CreateSimplePipelineModelArtifactsInner](rapidata/api_client/docs/CreateSimplePipelineModelArtifactsInner.md)
 - [CreateSimplePipelineModelPipelineStepsInner](rapidata/api_client/docs/CreateSimplePipelineModelPipelineStepsInner.md)
 - [CreateUnsupportedOrderModel](rapidata/api_client/docs/CreateUnsupportedOrderModel.md)
 - [CustomUserFilterModel](rapidata/api_client/docs/CustomUserFilterModel.md)
 - [Datapoint](rapidata/api_client/docs/Datapoint.md)
 - [DatapointAsset](rapidata/api_client/docs/DatapointAsset.md)
 - [DatapointGetByIdGet200Response](rapidata/api_client/docs/DatapointGetByIdGet200Response.md)
 - [DatapointMetadataModel](rapidata/api_client/docs/DatapointMetadataModel.md)
 - [DatapointMetadataModelMetadataInner](rapidata/api_client/docs/DatapointMetadataModelMetadataInner.md)
 - [DatapointModel](rapidata/api_client/docs/DatapointModel.md)
 - [DatapointModelAsset](rapidata/api_client/docs/DatapointModelAsset.md)
 - [DatasetArtifactModel](rapidata/api_client/docs/DatasetArtifactModel.md)
 - [DatasetEvaluationStepModel](rapidata/api_client/docs/DatasetEvaluationStepModel.md)
 - [DemographicMetadataModel](rapidata/api_client/docs/DemographicMetadataModel.md)
 - [DemographicSelection](rapidata/api_client/docs/DemographicSelection.md)
 - [EarlyStoppingRefereeModel](rapidata/api_client/docs/EarlyStoppingRefereeModel.md)
 - [EmptyValidationTruth](rapidata/api_client/docs/EmptyValidationTruth.md)
 - [EvaluationWorkflowConfig](rapidata/api_client/docs/EvaluationWorkflowConfig.md)
 - [EvaluationWorkflowModel](rapidata/api_client/docs/EvaluationWorkflowModel.md)
 - [FeatureFlag](rapidata/api_client/docs/FeatureFlag.md)
 - [FeatureFlagModel](rapidata/api_client/docs/FeatureFlagModel.md)
 - [FeedbackModel](rapidata/api_client/docs/FeedbackModel.md)
 - [FileArtifactModel](rapidata/api_client/docs/FileArtifactModel.md)
 - [FileAsset](rapidata/api_client/docs/FileAsset.md)
 - [FileAssetMetadataInner](rapidata/api_client/docs/FileAssetMetadataInner.md)
 - [FileAssetModel](rapidata/api_client/docs/FileAssetModel.md)
 - [FileAssetModel1](rapidata/api_client/docs/FileAssetModel1.md)
 - [FileAssetModel1MetadataInner](rapidata/api_client/docs/FileAssetModel1MetadataInner.md)
 - [FileAssetModel2](rapidata/api_client/docs/FileAssetModel2.md)
 - [FileAssetModelMetadataInner](rapidata/api_client/docs/FileAssetModelMetadataInner.md)
 - [Filter](rapidata/api_client/docs/Filter.md)
 - [FilterOperator](rapidata/api_client/docs/FilterOperator.md)
 - [FreeTextPayload](rapidata/api_client/docs/FreeTextPayload.md)
 - [FreeTextRapidBlueprint](rapidata/api_client/docs/FreeTextRapidBlueprint.md)
 - [FreeTextResult](rapidata/api_client/docs/FreeTextResult.md)
 - [Gender](rapidata/api_client/docs/Gender.md)
 - [GenderUserFilterModel](rapidata/api_client/docs/GenderUserFilterModel.md)
 - [GetAvailableValidationSetsResult](rapidata/api_client/docs/GetAvailableValidationSetsResult.md)
 - [GetClassifyWorkflowResultOverviewResult](rapidata/api_client/docs/GetClassifyWorkflowResultOverviewResult.md)
 - [GetCompareWorkflowResultOverviewResult](rapidata/api_client/docs/GetCompareWorkflowResultOverviewResult.md)
 - [GetCompareWorkflowResultOverviewSmallResult](rapidata/api_client/docs/GetCompareWorkflowResultOverviewSmallResult.md)
 - [GetDatapointsByDatasetIdResult](rapidata/api_client/docs/GetDatapointsByDatasetIdResult.md)
 - [GetDatasetByIdResult](rapidata/api_client/docs/GetDatasetByIdResult.md)
 - [GetOrderByIdResult](rapidata/api_client/docs/GetOrderByIdResult.md)
 - [GetPipelineByIdResult](rapidata/api_client/docs/GetPipelineByIdResult.md)
 - [GetPipelineByIdResultArtifactsValue](rapidata/api_client/docs/GetPipelineByIdResultArtifactsValue.md)
 - [GetPublicOrdersResult](rapidata/api_client/docs/GetPublicOrdersResult.md)
 - [GetSimpleWorkflowResultOverviewResult](rapidata/api_client/docs/GetSimpleWorkflowResultOverviewResult.md)
 - [GetValidationSetByIdResult](rapidata/api_client/docs/GetValidationSetByIdResult.md)
 - [GetWorkflowByIdResult](rapidata/api_client/docs/GetWorkflowByIdResult.md)
 - [GetWorkflowByIdResultWorkflow](rapidata/api_client/docs/GetWorkflowByIdResultWorkflow.md)
 - [GetWorkflowProgressResult](rapidata/api_client/docs/GetWorkflowProgressResult.md)
 - [GetWorkflowResultOverviewResult](rapidata/api_client/docs/GetWorkflowResultOverviewResult.md)
 - [IWorkflowModelPagedResult](rapidata/api_client/docs/IWorkflowModelPagedResult.md)
 - [IdentityReadBridgeTokenGet202Response](rapidata/api_client/docs/IdentityReadBridgeTokenGet202Response.md)
 - [ImageDimensionMetadata](rapidata/api_client/docs/ImageDimensionMetadata.md)
 - [ImageDimensionMetadataModel](rapidata/api_client/docs/ImageDimensionMetadataModel.md)
 - [ImportFromFileResult](rapidata/api_client/docs/ImportFromFileResult.md)
 - [ImportValidationSetFromFileResult](rapidata/api_client/docs/ImportValidationSetFromFileResult.md)
 - [InProgressRapidModel](rapidata/api_client/docs/InProgressRapidModel.md)
 - [LabelingSelection](rapidata/api_client/docs/LabelingSelection.md)
 - [LanguageUserFilterModel](rapidata/api_client/docs/LanguageUserFilterModel.md)
 - [Line](rapidata/api_client/docs/Line.md)
 - [LinePayload](rapidata/api_client/docs/LinePayload.md)
 - [LinePoint](rapidata/api_client/docs/LinePoint.md)
 - [LineRapidBlueprint](rapidata/api_client/docs/LineRapidBlueprint.md)
 - [LineResult](rapidata/api_client/docs/LineResult.md)
 - [LineTruth](rapidata/api_client/docs/LineTruth.md)
 - [LocateBoxTruth](rapidata/api_client/docs/LocateBoxTruth.md)
 - [LocateCoordinate](rapidata/api_client/docs/LocateCoordinate.md)
 - [LocatePayload](rapidata/api_client/docs/LocatePayload.md)
 - [LocateRapidBlueprint](rapidata/api_client/docs/LocateRapidBlueprint.md)
 - [LocateResult](rapidata/api_client/docs/LocateResult.md)
 - [LocationMetadata](rapidata/api_client/docs/LocationMetadata.md)
 - [LocationMetadataExistsFilterConfig](rapidata/api_client/docs/LocationMetadataExistsFilterConfig.md)
 - [LocationMetadataModel](rapidata/api_client/docs/LocationMetadataModel.md)
 - [LogicOperator](rapidata/api_client/docs/LogicOperator.md)
 - [MetadataVisibilities](rapidata/api_client/docs/MetadataVisibilities.md)
 - [MultiAsset](rapidata/api_client/docs/MultiAsset.md)
 - [MultiAssetModel](rapidata/api_client/docs/MultiAssetModel.md)
 - [MultiAssetModel1](rapidata/api_client/docs/MultiAssetModel1.md)
 - [MultiAssetModel1AssetsInner](rapidata/api_client/docs/MultiAssetModel1AssetsInner.md)
 - [MultiAssetModel2](rapidata/api_client/docs/MultiAssetModel2.md)
 - [NaiveRefereeConfig](rapidata/api_client/docs/NaiveRefereeConfig.md)
 - [NaiveRefereeModel](rapidata/api_client/docs/NaiveRefereeModel.md)
 - [NamedClassification](rapidata/api_client/docs/NamedClassification.md)
 - [NamedEntityPayload](rapidata/api_client/docs/NamedEntityPayload.md)
 - [NamedEntityRapidBlueprint](rapidata/api_client/docs/NamedEntityRapidBlueprint.md)
 - [NamedEntityResult](rapidata/api_client/docs/NamedEntityResult.md)
 - [NamedEntityTruth](rapidata/api_client/docs/NamedEntityTruth.md)
 - [NeverEndingRefereeConfig](rapidata/api_client/docs/NeverEndingRefereeConfig.md)
 - [NewsletterModel](rapidata/api_client/docs/NewsletterModel.md)
 - [NotAvailableYetResult](rapidata/api_client/docs/NotAvailableYetResult.md)
 - [NotStartedRapidModel](rapidata/api_client/docs/NotStartedRapidModel.md)
 - [NullAsset](rapidata/api_client/docs/NullAsset.md)
 - [NullAssetModel](rapidata/api_client/docs/NullAssetModel.md)
 - [NullAssetModel1](rapidata/api_client/docs/NullAssetModel1.md)
 - [NullAssetModel2](rapidata/api_client/docs/NullAssetModel2.md)
 - [OnlinePairMakerConfig](rapidata/api_client/docs/OnlinePairMakerConfig.md)
 - [OnlinePairMakerConfigModel](rapidata/api_client/docs/OnlinePairMakerConfigModel.md)
 - [OnlinePairMakerInformation](rapidata/api_client/docs/OnlinePairMakerInformation.md)
 - [OrderModel](rapidata/api_client/docs/OrderModel.md)
 - [OrderModelPagedResult](rapidata/api_client/docs/OrderModelPagedResult.md)
 - [OrderState](rapidata/api_client/docs/OrderState.md)
 - [OriginalFilenameMetadata](rapidata/api_client/docs/OriginalFilenameMetadata.md)
 - [OriginalFilenameMetadataModel](rapidata/api_client/docs/OriginalFilenameMetadataModel.md)
 - [PageInfo](rapidata/api_client/docs/PageInfo.md)
 - [PipelineIdWorkflowPutRequest](rapidata/api_client/docs/PipelineIdWorkflowPutRequest.md)
 - [PolygonPayload](rapidata/api_client/docs/PolygonPayload.md)
 - [PolygonRapidBlueprint](rapidata/api_client/docs/PolygonRapidBlueprint.md)
 - [PolygonResult](rapidata/api_client/docs/PolygonResult.md)
 - [PolygonTruth](rapidata/api_client/docs/PolygonTruth.md)
 - [PreArrangedPairMakerConfig](rapidata/api_client/docs/PreArrangedPairMakerConfig.md)
 - [PreArrangedPairMakerConfigModel](rapidata/api_client/docs/PreArrangedPairMakerConfigModel.md)
 - [PreArrangedPairMakerInformation](rapidata/api_client/docs/PreArrangedPairMakerInformation.md)
 - [PrivateTextMetadataInput](rapidata/api_client/docs/PrivateTextMetadataInput.md)
 - [ProbabilisticAttachCategoryRefereeConfig](rapidata/api_client/docs/ProbabilisticAttachCategoryRefereeConfig.md)
 - [ProblemDetails](rapidata/api_client/docs/ProblemDetails.md)
 - [PromptMetadata](rapidata/api_client/docs/PromptMetadata.md)
 - [PromptMetadataInput](rapidata/api_client/docs/PromptMetadataInput.md)
 - [PromptMetadataModel](rapidata/api_client/docs/PromptMetadataModel.md)
 - [PublicOrderModel](rapidata/api_client/docs/PublicOrderModel.md)
 - [PublicTextMetadataInput](rapidata/api_client/docs/PublicTextMetadataInput.md)
 - [QueryCampaignsModel](rapidata/api_client/docs/QueryCampaignsModel.md)
 - [QueryModel](rapidata/api_client/docs/QueryModel.md)
 - [QueryValidationRapidsResult](rapidata/api_client/docs/QueryValidationRapidsResult.md)
 - [QueryValidationRapidsResultAsset](rapidata/api_client/docs/QueryValidationRapidsResultAsset.md)
 - [QueryValidationRapidsResultPagedResult](rapidata/api_client/docs/QueryValidationRapidsResultPagedResult.md)
 - [QueryValidationSetModel](rapidata/api_client/docs/QueryValidationSetModel.md)
 - [QueryWorkflowsModel](rapidata/api_client/docs/QueryWorkflowsModel.md)
 - [RankedDatapointModel](rapidata/api_client/docs/RankedDatapointModel.md)
 - [RapidAnswer](rapidata/api_client/docs/RapidAnswer.md)
 - [RapidAnswerResult](rapidata/api_client/docs/RapidAnswerResult.md)
 - [RapidResultModel](rapidata/api_client/docs/RapidResultModel.md)
 - [RapidResultModelResult](rapidata/api_client/docs/RapidResultModelResult.md)
 - [RapidSkippedModel](rapidata/api_client/docs/RapidSkippedModel.md)
 - [ReadBridgeTokenKeysResult](rapidata/api_client/docs/ReadBridgeTokenKeysResult.md)
 - [RegisterTemporaryCustomerModel](rapidata/api_client/docs/RegisterTemporaryCustomerModel.md)
 - [RegisterTemporaryCustomerResult](rapidata/api_client/docs/RegisterTemporaryCustomerResult.md)
 - [RootFilter](rapidata/api_client/docs/RootFilter.md)
 - [SendCompletionMailStepModel](rapidata/api_client/docs/SendCompletionMailStepModel.md)
 - [Shape](rapidata/api_client/docs/Shape.md)
 - [SimpleWorkflowConfig](rapidata/api_client/docs/SimpleWorkflowConfig.md)
 - [SimpleWorkflowConfigModel](rapidata/api_client/docs/SimpleWorkflowConfigModel.md)
 - [SimpleWorkflowConfigModelBlueprint](rapidata/api_client/docs/SimpleWorkflowConfigModelBlueprint.md)
 - [SimpleWorkflowGetResultOverviewGet200Response](rapidata/api_client/docs/SimpleWorkflowGetResultOverviewGet200Response.md)
 - [SimpleWorkflowModel](rapidata/api_client/docs/SimpleWorkflowModel.md)
 - [SimpleWorkflowModel1](rapidata/api_client/docs/SimpleWorkflowModel1.md)
 - [SimpleWorkflowModelBlueprint](rapidata/api_client/docs/SimpleWorkflowModelBlueprint.md)
 - [SkipResult](rapidata/api_client/docs/SkipResult.md)
 - [SortCriterion](rapidata/api_client/docs/SortCriterion.md)
 - [SortDirection](rapidata/api_client/docs/SortDirection.md)
 - [StaticSelection](rapidata/api_client/docs/StaticSelection.md)
 - [SubmitCocoModel](rapidata/api_client/docs/SubmitCocoModel.md)
 - [SubmitCocoResult](rapidata/api_client/docs/SubmitCocoResult.md)
 - [TextAsset](rapidata/api_client/docs/TextAsset.md)
 - [TextAssetModel](rapidata/api_client/docs/TextAssetModel.md)
 - [TextAssetModel1](rapidata/api_client/docs/TextAssetModel1.md)
 - [TextAssetModel2](rapidata/api_client/docs/TextAssetModel2.md)
 - [TextMetadata](rapidata/api_client/docs/TextMetadata.md)
 - [TextMetadataModel](rapidata/api_client/docs/TextMetadataModel.md)
 - [TranscriptionMetadata](rapidata/api_client/docs/TranscriptionMetadata.md)
 - [TranscriptionMetadataInput](rapidata/api_client/docs/TranscriptionMetadataInput.md)
 - [TranscriptionMetadataModel](rapidata/api_client/docs/TranscriptionMetadataModel.md)
 - [TranscriptionPayload](rapidata/api_client/docs/TranscriptionPayload.md)
 - [TranscriptionRapidBlueprint](rapidata/api_client/docs/TranscriptionRapidBlueprint.md)
 - [TranscriptionResult](rapidata/api_client/docs/TranscriptionResult.md)
 - [TranscriptionTruth](rapidata/api_client/docs/TranscriptionTruth.md)
 - [TranscriptionWord](rapidata/api_client/docs/TranscriptionWord.md)
 - [TranslatedPromptMetadataModel](rapidata/api_client/docs/TranslatedPromptMetadataModel.md)
 - [TranslatedString](rapidata/api_client/docs/TranslatedString.md)
 - [UnlockOrderResult](rapidata/api_client/docs/UnlockOrderResult.md)
 - [UpdateAccessModel](rapidata/api_client/docs/UpdateAccessModel.md)
 - [UpdateCampaignModel](rapidata/api_client/docs/UpdateCampaignModel.md)
 - [UpdateOrderModel](rapidata/api_client/docs/UpdateOrderModel.md)
 - [UploadCocoResult](rapidata/api_client/docs/UploadCocoResult.md)
 - [UploadDatapointsResult](rapidata/api_client/docs/UploadDatapointsResult.md)
 - [UploadFilesFromS3BucketModel](rapidata/api_client/docs/UploadFilesFromS3BucketModel.md)
 - [UploadTextSourcesToDatasetModel](rapidata/api_client/docs/UploadTextSourcesToDatasetModel.md)
 - [UserScoreUserFilterModel](rapidata/api_client/docs/UserScoreUserFilterModel.md)
 - [ValidationChance](rapidata/api_client/docs/ValidationChance.md)
 - [ValidationImportPostRequestBlueprint](rapidata/api_client/docs/ValidationImportPostRequestBlueprint.md)
 - [ValidationSelection](rapidata/api_client/docs/ValidationSelection.md)
 - [ValidationSetModel](rapidata/api_client/docs/ValidationSetModel.md)
 - [ValidationSetModelPagedResult](rapidata/api_client/docs/ValidationSetModelPagedResult.md)
 - [ValidationSetOverviewModel](rapidata/api_client/docs/ValidationSetOverviewModel.md)
 - [WorkflowAggregationStepModel](rapidata/api_client/docs/WorkflowAggregationStepModel.md)
 - [WorkflowArtifactModel](rapidata/api_client/docs/WorkflowArtifactModel.md)
 - [WorkflowConfigArtifactModel](rapidata/api_client/docs/WorkflowConfigArtifactModel.md)
 - [WorkflowConfigArtifactModelWorkflowConfig](rapidata/api_client/docs/WorkflowConfigArtifactModelWorkflowConfig.md)
 - [WorkflowLabelingStepModel](rapidata/api_client/docs/WorkflowLabelingStepModel.md)
 - [WorkflowSplitModel](rapidata/api_client/docs/WorkflowSplitModel.md)
 - [WorkflowSplitModelFilterConfigsInner](rapidata/api_client/docs/WorkflowSplitModelFilterConfigsInner.md)
 - [WorkflowState](rapidata/api_client/docs/WorkflowState.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="bearer"></a>
### bearer

- **Type**: API key
- **API key parameter name**: Authorization
- **Location**: HTTP header

<a id="oauth2"></a>
### oauth2



## Author




